#!/usr/bin/env bash

HOSTNAME=${1:-localhost}
PORT=${2:-9200}
PREFIX=${3:-octoperf_}

createIndex() {
  echo "Creating index: ${PREFIX}${1}"
  curl -H 'Content-Type: application/json' -XPUT ${HOSTNAME}:${PORT}/${PREFIX}${1} -d @${1}.json
}

reindex() {
  createIndex ${2}

  echo "Reindexing from index '$1', with type '$2' to index '${PREFIX}${2}'"
  curl -H 'Content-Type: application/json' \
    -XPOST \
    -d "{ \"source\": { \"index\": \"${1}\", \"type\": \"${2}\" }, \"dest\": { \"index\": \"${PREFIX}${2}\" } }" \
    --max-time 7200 \
    ${HOSTNAME}:${PORT}/_reindex?wait_for_completion=true
}

# DESIGN
reindex "design" "apm"
reindex "design" "auditlog"
reindex "design" "benchloadgenerator"
reindex "design" "benchreport"
reindex "design" "benchresult"
reindex "design" "correlationframework"
reindex "design" "correlationrule"
reindex "design" "dockerbatch"
reindex "design" "dockercloudinstance"
reindex "design" "dockerprovider"
reindex "design" "dockerproviderconfig"
reindex "design" "httpserver"
reindex "design" "project"
reindex "design" "scenario"
reindex "design" "slaprofile"
reindex "design" "socialconnection"
reindex "design" "softwareversion"
reindex "design" "user"
reindex "design" "variablewrapper"
reindex "design" "virtualuser"
reindex "design" "webhook"
reindex "design" "workspace"
reindex "design" "workspacemember"

# MONITORING
reindex "monitoring" "agent"
reindex "monitoring" "monitorconnection"
reindex "monitoring" "numbercountervalue"
reindex "monitoring" "textualcountervalue"
reindex "monitoring" "thresholdalarm"

# ANALYSIS

reindex "analysis" "container"
reindex "analysis" "dockerlog"
reindex "analysis" "error"
reindex "analysis" "hit"
reindex "analysis" "http"
reindex "analysis" "monitor"